Learn R Programming

ForecastTB (version 1.0.1)

choose_: Function to select the desired methods in the study

Description

Function to select the desired methods in the study

Usage

choose_(object)

Arguments

object

as output of 'prediction_errors()' function

Value

Returns error comparison for selected forecasting methods

Examples

Run this code
# NOT RUN {
a <- prediction_errors(data = nottem)
choose_(object = a)
# }

Run the code above in your browser using DataLab